# ERP Transformation
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/erp-transformation#overview)
  * [What Does ERP Transformation Mean?](https://help.sap.com/docs/leanix/ea/erp-transformation#what-does-erp-transformation-mean?)
  * [Reasons to Start an ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation#reasons-to-start-an-erp-transformation)
  * [Why Do Organizations Struggle with ERP Transformations?](https://help.sap.com/docs/leanix/ea/erp-transformation#why-do-organizations-struggle-with-erp-transformations?)
  * [Benefits of ERP Transformation with SAP LeanIX](https://help.sap.com/docs/leanix/ea/erp-transformation#benefits-of-erp-transformation-with-sap-leanix)
  * [Benefits for Different Stakeholders](https://help.sap.com/docs/leanix/ea/erp-transformation#benefits-for-different-stakeholders)
  * [Which SAP LeanIX Products Are Needed for ERP Transformation?](https://help.sap.com/docs/leanix/ea/erp-transformation#which-sap-leanix-products-are-needed-for-erp-transformation?)
  * [How to Support ERP Transformation with SAP LeanIX?](https://help.sap.com/docs/leanix/ea/erp-transformation#how-to-support-erp-transformation-with-sap-leanix?)


Step-by-step guide for ERP Transformation using SAP LeanIX.
